<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Photo Gallery directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	M. Carroll 
Custom Field Type:
	Photo Image Gallery Checkbox Field
Name:
	photo_img_gallery_checkbox_field_render.cfc
Summary:
	Custom select field to select the custom element fields for the
		option id and name values.
	Added Properties to set the field name value, default field value, and field visibility.
ADF Requirements:
	CSData_1_0
	Scripts_1_0
Version:
	2.0
History:
	2009-08-04 - MFC - Created
	2010-08-19 - MFC - Updated the load JQuery and JQuery versions to use the global versioning.
	2015-07-08 - DJM - Converted to CFC
	2016-02-26 - DRM - Resource detection support
--->
<cfcomponent displayName="PhotoImageGalleryCheckboxField Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var fieldIDVal = arguments.fieldName;
		
		// Set the field ID
		if ( (NOT StructKeyExists(inputParameters, "fldName")) OR (LEN(inputParameters.fldName)) )
			fieldIDVal = inputParameters.fldName;
		
		// Check the default value
		if ( LEN(currentValue) LTE 0 ) {
			currentValue = 'no';
			// If defaulted to checked
			if ( inputParameters.defaultVal EQ "yes" )
				currentValue = 'yes';
		}
		
		renderJSFunctions(argumentCollection=arguments,fieldIDVal=fieldIDVal);
	</cfscript>
	
	<cfoutput>
		<div id="#arguments.fieldName#_renderCheckbox">
			<input type='checkbox' name='#arguments.fieldName#_checkbox' id='#arguments.fieldName#_checkbox' value='yes'>
		</div>
		
		<!--- hidden field to store the value --->
		<input type='hidden' name='#arguments.fieldName#' id='#fieldIDVal#' value='#currentValue#'>
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldIDVal" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
	</cfscript>
<cfoutput>
<script type="text/javascript">
<!--
jQuery(document).ready(function(){		
	// Check if we want to hide the field
	// Check if we are rendering the field 
	if ( '#inputParameters.renderField#' == 'yes' ) {
	
		// Set the value of the checkbox
		if ( jQuery('input[name=#arguments.fieldName#]').val() == 'yes' ) {
			jQuery('###arguments.fieldName#_checkbox').attr('checked', 'checked');
		}
					
		// On Change Action
		jQuery('###arguments.fieldName#_checkbox').change( function(){
			// Check the checkbox status
			if ( jQuery('###arguments.fieldName#_checkbox:checked').val() == 'yes' )
				currVal = "yes";
			else
				currVal = "no";
			// Set the form field
			jQuery('input[name=#arguments.fieldName#]').val(currVal);
		});
	}
	else {
		// Hide the field row
		jQuery("###arguments.fieldName#_renderCheckbox").hide();
	}
});

function #arguments.fieldIDVal#_setImgGalPageID(pageid) {
	// if the photo was stored into the image gallery, then store the page id
	if ( pageid > 0 )
	{
		// Sets value for hidden Image Gallery PageID field
		jQuery('###inputParameters.imgGalleryPageIDFldName#').val(pageid);
	}
}
function #arguments.fieldIDVal#_getImgGalPageID() {
	// Get value for hidden Image Gallery PageID field
	return jQuery('###inputParameters.imgGalleryPageIDFldName#').val();
}

// Function to set the field as disabled
function #arguments.fieldIDVal#_disableFld(){
	jQuery('###arguments.fieldName#_checkbox').attr('disabled', true);
}
// Function to set the field as enabled
function #arguments.fieldIDVal#_enableFld(){
	jQuery('###arguments.fieldName#_checkbox').attr('disabled', false);
}
//-->
</script>
</cfoutput>
</cffunction>


<cfscript>

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery");
	}
	public string function loadResourceDependencies()
	{
		application.ptPhotoGallery.scripts.loadJQuery();
	}
</cfscript>

</cfcomponent>